@@ -1,3 +1,5 @@
+from .colorit import *
+
 # Use this to ensure that ColorIt will be usable by certain command line interfaces
 init_colorit()
 
@@ -26,9 +28,6 @@ print(background("This color has a custom grey background", (150, 150, 150)))
 # Combination
 print(
     background(
-        color("This text is blue with a white background", Colors.BLUE), Colors.WHITE
+        color("This text is blue with a white background", Colors.blue), Colors.white
     )
 )
-
-# If you are using Windows Command Line, this is so that it doesn't close immediately
-input()
